Servo, the embeddable, independent, memory-safe, modular, parallel web rendering engine
Author: The Servo Project Developers
Description: Servo is a web rendering engine written in Rust, with WebGL and WebGPU support, and adaptable to desktop, mobile, and embedded applications.
Keywords: servo, servo engine, servo rendering engine, web engine, web rendering engine, web browser, web browser engine, rust

The embeddable, independent, memory-safe, modular, parallel web rendering engine

Servo is a web rendering engine written in Rust, with WebGL and WebGPU support, and adaptable to desktop, mobile, and embedded applications.

2024-06-28

This month in Servo: text fields, better emoji, devtools, and more!

Plus font rendering performance, OpenHarmony and AddressSanitizer builds, and a new AI policy.

2024-05-30

This month in Servo: new CSS units, color emoji, servoshell, and more!

Big changes to the font system and servoshell, plus improvements to flexbox, tables, DOM support, and the embedding API.

2024-04-26

This month in Servo: Acid2 redux, Servo book, Qt demo, and more!

A new layout milestone, revamped docs, faster builds, plus embedding, video, fonts, WebGPU, and CSS improvements.

2024-04-15

Servo and SpiderMonkey

A new report on Servo’s integration with SpiderMonkey, and our proposal for improving its modularity.

## Contact

- Zulip chat: https://servo.zulipchat.com/

- GitHub discussions: https://github.com/servo/servo/discussions

- Email: [email protected]

- Mastodon: https://floss.social/@servo

- Twitter: https://twitter.com/ServoDev

## Downloads

Windows EXE ? sha256

Windows ZIP ? sha256

macOS (x64) ? sha256

Linux (x64) ? sha256

## Sponsorship

You can now help fund the Servo project by sponsoring us on GitHub or Open Collective.

For more information about how to sponsor the project, visit the sponsorship page.